jQuery( function( $ ) {
	/**
	 * Document Link Metabox JS
	 */
	const dlpDocumentLink = function() {
        $( '#dlp_add_file_button' ).on( 'click', this.handleAddFile );
        $( '#dlp_remove_file_button' ).on( 'click', this.handleRemoveFile );
        $( '#dlp_document_link_type' ).on( 'change', this.handleSelectBox );
    };

    dlpDocumentLink.wpMedia = null;

    /**
	 * Render second option
	 */
	dlpDocumentLink.prototype.handleSelectBox = function( event ) {
        const $this = $( this );
        const value = $this.find( ':selected' ).val();
        const $file_details = $( '#dlp_file_attachment_details' );
        const $url_details = $( '#dlp_link_url_details' );
        const $file_size_input = $( '#dlp_file_size_input' );

        switch ( value ) {
            case 'file':
                $url_details.removeClass( 'active' );
                $file_details.addClass( 'active' );
                $file_size_input.prop( 'disabled', true );
                break;
            case 'url':
                $url_details.addClass( 'active' );
                $file_details.removeClass( 'active' );
                $file_size_input.removeAttr( 'disabled' );
                break;
            case 'none':
                $url_details.removeClass( 'active' );
                $file_details.removeClass( 'active' );
                $file_size_input.removeAttr( 'disabled' );
                break;
            default:
                $url_details.removeClass( 'active' );
                $file_details.removeClass( 'active' );
                $file_size_input.removeAttr( 'disabled' );
                break;
        }
    };

    /**
	 * Handle Add File (WP Media)
	 */
    dlpDocumentLink.prototype.handleAddFile = function( event ) {
        event.preventDefault();

        const $this = $( this );
        const $file_name = $( '#dlp_file_name' );
        const $file_name_text = $( '.dlp_file_name_text' );
        const $file_id = $( '#dlp_file_id' );
        const $file_attached_area = $( '.dlp_file_attached' );


        if ( dlpDocumentLink.wpMedia !== null ) {
            dlpDocumentLink.wpMedia.open();
            return;
        }

        dlpDocumentLink.wpMedia = wp.media({
            title: dlpAdminObject.i18n.select_file,
            button: {
                text: dlpAdminObject.i18n.add_file
            }
        });

        dlpDocumentLink.wpMedia.on( 'select', function () {
            const selection = dlpDocumentLink.wpMedia.state().get('selection');

            selection.map( function (attachment) {
                attachment = attachment.toJSON();

                $file_name.val( attachment.filename );
                $file_name_text.text( attachment.filename );
                $file_id.val( attachment.id );
                $file_attached_area.addClass( 'active' );
                $this.text( dlpAdminObject.i18n.replace_file );
            });
        });

        dlpDocumentLink.wpMedia.open();
    };

    /**
	 * Handle Remove File
	 */
    dlpDocumentLink.prototype.handleRemoveFile = function( event ) {
        event.preventDefault();

        const $file_name = $( '#dlp_file_name' );
        const $file_id = $( '#dlp_file_id' );
        const $file_attached_area = $( '.dlp_file_attached' );
        const $add_file_button = $( '#dlp_add_file_button' );

        $file_attached_area.removeClass( 'active' );
        $file_name.val('');
        $file_id.val('');
        $add_file_button.text( dlpAdminObject.i18n.add_file );
    };

	/**
	 * Init dlpDocumentLink.
	 */
	new dlpDocumentLink();
} );