import { has, isEmpty } from 'lodash';
import axios from "axios";
import qs from 'qs';

import { __ } from '@wordpress/i18n'
import { addAction, addFilter } from "@wordpress/hooks";

import { SetupWizardSettings, getParsedAjaxError } from '../../../../../vendor/barn2/setup-wizard/resources/js/utilities';
import Layout from './components/layout';

addFilter( 'barn2_setup_wizard_steps', 'dlp-wizard', ( steps ) => {
	steps[ 1 ].container = Layout;
	return steps
} );

addAction( 'barn2_wizard_on_restart', 'dlp-wizard', ( wizard ) => {
	console.log( 'restart' );
	wizard.setState( { wizard_loading: true, wizard_complete: true } );

	axios.post( SetupWizardSettings.ajax, qs.stringify(
		{
			action: `barn2_wizard_${ SetupWizardSettings.plugin_slug }_on_restart`,
			nonce: SetupWizardSettings.nonce,
		}
	 ) )
	.then(function (response) {

		if ( has( response, 'data.data.layout' ) ) {
			const layout = response.data.data.layout


			if ( layout === 'grid' ) {
				wizard.showStep( 'grid' )
				wizard.hideStep( 'table' )
				wizard.hideStep( 'filters' )
			}

			if ( layout === 'table' ) {
				wizard.showStep( 'table' )
				wizard.showStep( 'filters' )
				wizard.hideStep( 'grid' )
			}

			wizard.setState( { wizard_loading: false } );

			wizard.setStepsCompleted( true )

		}
	})
	.catch(function (error) {
		if ( error.response ) {
			if ( ! isEmpty( getParsedAjaxError( error.response ) ) ) {
				wizard.setErrorMessage( getParsedAjaxError( error.response ) );
			} else {
				wizard.setErrorMessage( error.response.statusText );
			}
		} else if (error.request) {
			wizard.setErrorMessage( __( 'The request was made but no response was received.' ) );
		} else {
			wizard.setErrorMessage( __( 'Something went wrong while making the request.' ) );
		}
	});

} )