<?php
namespace Barn2\Plugin\Document_Library_Pro\Integration;

use Barn2\DLP_Lib\Registerable,
	Barn2\DLP_Lib\Service,
	Barn2\Plugin\Document_Library_Pro\Posts_Table_Pro\Table_Args;

defined( 'ABSPATH' ) || exit;

/**
 * Handles integration with FacetWP
 *
 * @package   Barn2/document-library-pro
 * @author    Barn2 Plugins <info@barn2.com>
 * @license   GPL-3.0
 * @copyright Barn2 Media Ltd
 */
class FacetWP implements Registerable, Service {

	/**
	 * {@inheritdoc}
	 */
	public function register() {
		if ( ! class_exists( 'FacetWP' ) ) {
			return;
		}

		add_filter( 'facetwp_template_html', [ $this, 'render_document_library' ], 10, 2 );
	}

	/**
	 * Load the document library if template begins with 'dlp_'.
	 *
	 * @param string $output
	 * @param FacetWP_Renderer $renderer
	 * @return string
	 */
	public function render_document_library( $output, $renderer ) {
		// check if template name starts with dlp_
		if ( substr( $renderer->template['name'], 0, 4 ) !== 'dlp_' ) {
			return $output;
		}

		$output = '';
		$layout = Table_Args::get_user_defaults()['layout'];

		// add posts table init script if table layout
		if ( $layout === 'table' ) {
			$output .= $this->get_posts_table_script();
		}

		$output .= dlp_get_doc_library(
			array_merge(
				apply_filters( 'document_library_pro_facetwp_custom_args', [] ),
				[
					'folders'         => false,
					'filters'         => false,
					'search_box'      => false,
					'reset_button'    => false,
					'cache'           => false,
					'search_on_click' => false,
					'rows_per_page'   => $renderer->query_args['posts_per_page'],
					'include'         => implode( ',', $renderer->get_filtered_post_ids() )
				]
			)
		);

		return $output;
	}

	/**
	 * Generate script tag to re-init posts table after facet loading.
	 *
	 * @return string
	 */
	private function get_posts_table_script() {
		$script = "<script>
        ( function( $ ) {
            document.addEventListener( 'facetwp-loaded', function() {
                $( '.facetwp-template table' ).first().postsTable();
             } );
        } )( jQuery );
        </script>";

		return $script;
	}
}
