<?php
namespace Barn2\Plugin\Document_Library_Pro\Table_Data;

use Barn2\Plugin\Document_Library_Pro\Taxonomies,
	Barn2\Plugin\Document_Library_Pro\Posts_Table_Pro\Data\Abstract_Table_Data,
	Barn2\Plugin\Document_Library_Pro\Posts_Table_Pro\Util\Util;

defined( 'ABSPATH' ) || exit;

/**
 * Gets post data for the document tags column
 *
 * @package   Barn2\document-library-pro
 * @author    Barn2 Plugins <support@barn2.com>
 * @license   GPL-3.0
 * @copyright Barn2 Media Ltd
 */
class Document_Tags extends Abstract_Table_Data {

	private $taxonomy;
	private $date_format;
	private $is_date;

	/**
	 * Constructor.
	 *
	 * @param WP_Post $post
	 * @param Table_Args $args
	 */
	public function __construct( $post, $args ) {
		parent::__construct( $post, $args->links );

		$this->taxonomy    = Taxonomies::TAG_SLUG;
		$this->date_format = $args->date_format;
		$this->is_date     = in_array( $this->taxonomy, $args->date_columns, true );
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_data() {
		$terms = '';
		$sep   = parent::get_separator( 'terms' );

		if ( array_intersect( [ 'all', $this->taxonomy ], $this->links ) ) {
			$terms = Util::empty_if_false( get_the_term_list( $this->post->ID, $this->taxonomy, '', $sep ) );
		} else {
			$terms = Util::get_the_term_names( $this->post, $this->taxonomy, $sep );
		}

		// If taxonomy is a date and there's only 1 term, format value in required date format.
		if ( $this->is_date && $this->date_format && ( false === strpos( $terms, $sep ) ) ) {
			$timestamp = $this->convert_to_timestamp( $terms );

			if ( $timestamp ) {
				$terms = gmdate( $this->date_format, $timestamp );
			}
		}

		return apply_filters( 'document_library_pro_data_tags', $terms, $this->post );

	}

	/**
	 * Get the sort data.
	 *
	 * @return int|true|string
	 */
	public function get_sort_data() {
		if ( $this->is_date ) {
			$date_terms = get_the_terms( $this->post->ID, $this->taxonomy );

			if ( is_array( $date_terms ) && 1 === count( $date_terms ) ) {
				$date_term = reset( $date_terms );

				// Format the hidden date column for sorting
				$timestamp = $this->convert_to_timestamp( $date_term->name );

				if ( $timestamp ) {
					return $timestamp;
				}
			}

			// Need to return non-empty string to ensure all cells have a data-sort value.
			return '0';
		}
		return '';
	}

	/**
	 * Convert date to timestamp.
	 *
	 * @param string $date
	 * @return int|bool
	 */
	private function convert_to_timestamp( $date ) {
		if ( ! $date ) {
			return false;
		}

		if ( apply_filters( 'document_library_pro_taxonomy_is_eu_au_date', false, $this->taxonomy ) ) {
			$date = str_replace( '/', '-', $date );
		}

		return Util::strtotime( $date );
	}

}
